#!/usr/bin/env python
# encoding: utf-8

class KKBOXTerritory:
    '''
    The territory of the KKBOX's service.
    '''
    TAIWAN = 'TW'
    HONGKONG = 'HK'
    SINGAPORE = 'SG'
    MALAYSIA = 'MA'
    JAPAN = 'JP'